var __defProp = Object.defineProperty;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, {enumerable: true, configurable: true, writable: true, value}) : obj[key] = value;
var __objSpread = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

// src/index.ts
import {getHighlighter} from "shiki";
import deasync from "deasync";
import Debug from "debug";
var debug = Debug("markdown-it-shiki");
function getThemeName(theme) {
  if (typeof theme === "string")
    return theme;
  return theme.name;
}
function resolveOptions(options) {
  const themes = [];
  let darkModeThemes;
  if (!options.theme) {
    themes.push("nord");
  } else if (typeof options.theme === "string") {
    themes.push(options.theme);
  } else {
    if ("dark" in options.theme || "light" in options.theme) {
      darkModeThemes = options.theme;
      themes.push(options.theme.dark);
      themes.push(options.theme.light);
    } else {
      themes.push(options.theme);
    }
  }
  return __objSpread(__objSpread({}, options), {
    themes,
    darkModeThemes: darkModeThemes ? {
      dark: getThemeName(darkModeThemes.dark),
      light: getThemeName(darkModeThemes.light)
    } : void 0
  });
}
var MarkdownItShiki = (markdownit, options = {}) => {
  let _highlighter = options.highlighter;
  const {
    timeout = 1e4,
    langs,
    themes,
    darkModeThemes
  } = resolveOptions(options);
  if (!_highlighter) {
    getHighlighter({themes, langs}).then((h) => {
      _highlighter = h;
    });
  }
  markdownit.options.highlight = (code, lang) => {
    if (!_highlighter) {
      debug("awaiting getHighlighter()");
      let count = timeout / 200;
      while (!_highlighter) {
        deasync.sleep(200);
        count -= 1;
        if (count <= 0)
          throw new Error("Shiki.getHighlighter() never gets resolved");
      }
      debug("getHighlighter() resolved");
    }
    if (darkModeThemes) {
      const dark = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.dark).replace('<pre class="shiki"', '<pre class="shiki shiki-dark"');
      const light = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.light).replace('<pre class="shiki"', '<pre class="shiki shiki-light"');
      return `<div class="shiki-container">${dark}${light}</div>`;
    } else {
      return _highlighter.codeToHtml(code, lang || "text");
    }
  };
};
var src_default = MarkdownItShiki;
export {
  src_default as default,
  resolveOptions
};
